Stan Math Library: stan/math/prim/mat/prob/inv_wishart_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
inv_wishart_rng.hpp File Reference
`#include <stan/math/prim/mat/err/check_ldlt_factor.hpp>`
`#include <stan/math/prim/scal/err/check_greater.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/mat/fun/log_determinant_ldlt.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_ldlt.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/mat/prob/wishart_rng.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic > | stan::math::inv_wishart_rng (const double nu, const Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic > &S, RNG &rng)

[ Stan Home Page ] © 2011–2016, Stan Development Team.